@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 
 import os
@@ -34,9 +34,9 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     """ Verify if we have the right parameters """
     if (alg.parameterAsString(parameters, 'input_txt', context)
             and alg.parameterAsString(parameters, 'input', context)):
-        return alg.tr("You need to set either an input ASCII file or inline data!")
+        return False, alg.tr("You need to set either an input ASCII file or inline data!")
 
-    return None
+    return True, None
 
 
 def processCommand(alg, parameters, context, feedback):
@@ -60,4 +60,4 @@ def processOutputs(alg, parameters, context, feedback):
     fileName = alg.parameterAsOutputLayer(parameters, 'output', context)
     grassName = alg.exportedLayers['map']
     dataType = 'auto'
-    alg.exportVectorLayer(grassName, fileName, dataType)
+    alg.exportVectorLayer(grassName, fileName, dataType=dataType)
