@@ -23,12 +23,13 @@ __copyright__ = '(C) 2010, Michael Minn'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 from qgis.PyQt.QtCore import QCoreApplication
 
 from qgis.core import (QgsProcessingParameterField,
                        QgsProcessing,
+                       QgsProcessingAlgorithm,
                        QgsProcessingFeatureSource)
 from processing.algs.qgis.QgisAlgorithm import QgisFeatureBasedAlgorithm
 
@@ -37,6 +38,9 @@ class DeleteColumn(QgisFeatureBasedAlgorithm):
 
     COLUMNS = 'COLUMN'
 
+    def flags(self):
+        return super().flags() & ~QgsProcessingAlgorithm.FlagSupportsInPlaceEdits
+
     def tags(self):
         return self.tr('drop,delete,remove,fields,columns,attributes').split(',')
 
@@ -66,7 +70,7 @@ class DeleteColumn(QgisFeatureBasedAlgorithm):
         return self.tr('Drop field(s)')
 
     def outputName(self):
-        return self.tr('Fields dropped')
+        return self.tr('Remaining fields')
 
     def prepareAlgorithm(self, parameters, context, feedback):
         self.fields_to_delete = self.parameterAsFields(parameters, self.COLUMNS, context)
