@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import os
 from qgis.PyQt.QtGui import QIcon
@@ -80,6 +80,12 @@ class SagaAlgorithmProvider(QgsProcessingProvider):
     def setActive(self, active):
         ProcessingConfig.setSettingValue('ACTIVATE_SAGA', active)
 
+    def canBeActivated(self):
+        version = SagaUtils.getInstalledVersion(True)
+        if version is not None and version.startswith(REQUIRED_VERSION):
+            return True
+        return False
+
     def loadAlgorithms(self):
         version = SagaUtils.getInstalledVersion(True)
         if version is None:
@@ -123,11 +129,17 @@ class SagaAlgorithmProvider(QgsProcessingProvider):
         return 'saga'
 
     def defaultVectorFileExtension(self, hasGeometry=True):
-        return 'shp'
+        return 'shp' if hasGeometry else 'dbf'
 
     def defaultRasterFileExtension(self):
         return 'sdat'
 
+    def supportedOutputRasterLayerExtensions(self):
+        return ['sdat']
+
+    def supportedOutputVectorLayerExtensions(self):
+        return ['shp', 'dbf']
+
     def supportedOutputTableExtensions(self):
         return ['dbf']
 
