@@ -23,14 +23,19 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 
 from qgis.PyQt.QtCore import QCoreApplication
+from qgis.PyQt.QtGui import QIcon
 
 
 class ContextAction:
 
+    def __init__(self):
+        self.name = None
+        self.is_separator = False
+
     def setData(self, itemData, toolbox):
         self.itemData = itemData
         self.toolbox = toolbox
@@ -39,3 +44,12 @@ class ContextAction:
         if context == '':
             context = self.__class__.__name__
         return QCoreApplication.translate(context, string)
+
+    def icon(self):
+        return QIcon()
+
+    def isEnabled(self):
+        return True
+
+    def execute(self):
+        pass
