@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import os
 import configparser
@@ -49,19 +49,31 @@ def algorithmHelp(id):
     alg = QgsApplication.processingRegistry().algorithmById(id)
     if alg is not None:
         print('{} ({})\n'.format(alg.displayName(), alg.id()))
-        print(alg.shortHelpString())
+        if alg.shortDescription():
+            print(alg.shortDescription() + '\n')
+        if alg.shortHelpString():
+            print(alg.shortHelpString() + '\n')
         print('\n----------------')
         print('Input parameters')
         print('----------------')
         for p in alg.parameterDefinitions():
-            print('\n{}:  <{}>'.format(p.name(), p.__class__.__name__))
-            if p.description():
-                print('\t' + p.description())
+            print('\n{}: {}'.format(p.name(), p.description()))
+
+            print('\n\tParameter type:\t{}'.format(p.__class__.__name__))
 
             if isinstance(p, QgsProcessingParameterEnum):
                 opts = []
                 for i, o in enumerate(p.options()):
-                    opts.append('\t\t{} - {}'.format(i, o))
+                    opts.append('\t\t- {}: {}'.format(i, o))
+                print('\n\tAvailable values:\n{}'.format('\n'.join(opts)))
+
+            parameter_type = QgsApplication.processingRegistry().parameterType(p.type())
+            accepted_types = parameter_type.acceptedPythonTypes() if parameter_type is not None else []
+            if accepted_types:
+                opts = []
+                for t in accepted_types:
+                    opts.append('\t\t- {}'.format(t))
+                print('\n\tAccepted data types:')
                 print('\n'.join(opts))
 
         print('\n----------------')
@@ -77,11 +89,28 @@ def algorithmHelp(id):
         print('Algorithm "{}" not found.'.format(id))
 
 
-def run(algOrName, parameters, onFinish=None, feedback=None, context=None):
-    """Executes given algorithm and returns its outputs as dictionary
-    object.
+def run(algOrName, parameters, onFinish=None, feedback=None, context=None, is_child_algorithm=False):
     """
-    return Processing.runAlgorithm(algOrName, parameters, onFinish, feedback, context)
+    Executes given algorithm and returns its outputs as dictionary object.
+
+    :param algOrName: Either an instance of an algorithm, or an algorithm's ID
+    :param parameters: Algorithm parameters dictionary
+    :param onFinish: optional function to run after the algorithm has completed
+    :param feedback: Processing feedback object
+    :param context: Processing context object
+    :param is_child_algorithm: Set to True if this algorithm is being run as part of a larger algorithm,
+    i.e. it is a sub-part of an algorithm which calls other Processing algorithms.
+    """
+    if onFinish or not is_child_algorithm:
+        return Processing.runAlgorithm(algOrName, parameters, onFinish, feedback, context)
+    else:
+        # for child algorithms, we disable to default post-processing step where layer ownership
+        # is transferred from the context to the caller. In this case, we NEED the ownership to remain
+        # with the context, so that further steps in the algorithm have guaranteed access to the layer.
+        def post_process(_alg, _context, _feedback):
+            return
+
+        return Processing.runAlgorithm(algOrName, parameters, onFinish=post_process, feedback=feedback, context=context)
 
 
 def runAndLoadResults(algOrName, parameters, feedback=None, context=None):
@@ -115,7 +144,7 @@ def createAlgorithmDialog(algOrName, parameters={}):
     and delete this dialog.
     """
     if isinstance(algOrName, QgsProcessingAlgorithm):
-        alg = algOrName
+        alg = algOrName.create()
     else:
         alg = QgsApplication.processingRegistry().createAlgorithmById(algOrName)
 
@@ -125,7 +154,7 @@ def createAlgorithmDialog(algOrName, parameters={}):
     dlg = alg.createCustomParametersWidget(iface.mainWindow())
 
     if not dlg:
-        dlg = AlgorithmDialog(alg)
+        dlg = AlgorithmDialog(alg, parent=iface.mainWindow())
 
     dlg.setParameters(parameters)
 
